package com.ruoyi.web.controller.crops;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.crops.domain.CropsComprehensiveData;
import com.ruoyi.crops.service.ICropsComprehensiveDataService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 作物综合数据Controller
 *
 * @author my
 * @date 2023-04-19
 */
@RestController
@RequestMapping("/crops/data")
public class CropsComprehensiveDataController extends BaseController
{
    @Autowired
    private ICropsComprehensiveDataService cropsComprehensiveDataService;

    /**
     * 查询作物综合数据列表
     */

    @GetMapping("/list")
    public TableDataInfo list(CropsComprehensiveData cropsComprehensiveData)
    {
//        startPage();
        List<CropsComprehensiveData> list = cropsComprehensiveDataService.selectCropsComprehensiveDataList(cropsComprehensiveData);
        return getDataTable(list);
    }

    /**
     * 导出作物综合数据列表
     */

    @Log(title = "作物综合数据", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CropsComprehensiveData cropsComprehensiveData)
    {
        List<CropsComprehensiveData> list = cropsComprehensiveDataService.selectCropsComprehensiveDataList(cropsComprehensiveData);
        ExcelUtil<CropsComprehensiveData> util = new ExcelUtil<CropsComprehensiveData>(CropsComprehensiveData.class);
        util.exportExcel(response, list, "作物综合数据数据");
    }

    /**
     * 获取作物综合数据详细信息
     */

    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(cropsComprehensiveDataService.selectCropsComprehensiveDataById(id));
    }

    /**
     * 新增作物综合数据
     */

    @Log(title = "作物综合数据", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CropsComprehensiveData cropsComprehensiveData)
    {
        return toAjax(cropsComprehensiveDataService.insertCropsComprehensiveData(cropsComprehensiveData));
    }

    /**
     * 修改作物综合数据
     */

    @Log(title = "作物综合数据", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CropsComprehensiveData cropsComprehensiveData)
    {
        return toAjax(cropsComprehensiveDataService.updateCropsComprehensiveData(cropsComprehensiveData));
    }

    /**
     * 删除作物综合数据
     */

    @Log(title = "作物综合数据", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(cropsComprehensiveDataService.deleteCropsComprehensiveDataByIds(ids));
    }
}
