package com.ruoyi.web.controller.crops;

import cn.hutool.http.HttpUtil;
import com.google.gson.Gson;
import com.google.gson.GsonBuilder;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.crops.domain.DeviceSense;
import com.ruoyi.crops.domain.gsonBean.GsonDeviceSenseBean;
import com.ruoyi.crops.service.IDeviceSenseService;
import com.ruoyi.crops.service.IWarningService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.web.bind.annotation.*;

import java.lang.reflect.Field;
import java.text.SimpleDateFormat;
import java.util.*;

@RestController
@RequestMapping("/crops/device")
public class DeviceSenseController {
    private static final Logger logger = LoggerFactory.getLogger("scheduled");

    @Value("${url.deviceSense}")
    String url;//指定UR

    @Autowired
    private IDeviceSenseService iDeviceSenseService;

    @Autowired
    private IWarningService iWarningService;

    /**
     * 根据时间查询设备传感数据
     *
     * @param startTime
     * @param endTime
     * @return
     */
    @GetMapping
    public List<DeviceSense> selectBytime(@RequestParam String startTime, @RequestParam String endTime) {
        return iDeviceSenseService.selectByTime(startTime, endTime);
    }

    /**
     * 定时任务调用接口获取数据插入数据库
     *
     * @throws Exception
     */
    @Scheduled(fixedDelay = 6 * 60 * 1000)
    public void getsense() throws Exception {
        String deviceId = "863070042491174-1-1";
        Map<String, Object> map = new HashMap<>();//存放参数
        map.put("deviceId", deviceId);
        //发送get请求
        String result = HttpUtil.createGet(url).form(map).execute().body();
        //格式化json时间类型数据
        Gson gson = new GsonBuilder().setDateFormat("yyyy/MM/dd HH:mm:ss").create();
        //格式化json，封装到GsonDeviceSenseBean类型
        GsonDeviceSenseBean model = gson.fromJson(result, GsonDeviceSenseBean.class);
        //创建DeviceSense对象，设置deviceId
        DeviceSense deviceSense = new DeviceSense();
        deviceSense.setDeviceId(deviceId);
        //通过反射获取成员变量name与json字段匹配入库
        Class clazz = Class.forName("com.ruoyi.crops.domain.DeviceSense");
        for (GsonDeviceSenseBean.AttDataList attDataList : model.data.attDataList) {
            //2.获取成员变量
            String attributeValue = attDataList.attributeValue;
            Field field = clazz.getDeclaredField(attDataList.attributeName);
            //设置私有变量也可访问
            field.setAccessible(true);
            //判断数据类型进行相应转换
            if (attributeValue != null) {
                switch (field.getType().getName()) {
                    case "java.lang.Double":
                        field.set(deviceSense, Double.valueOf(attributeValue));
                        break;
                    case "java.lang.Integer":
                        field.set(deviceSense, Integer.valueOf(attributeValue));
                        break;
                    case "java.lang.String":
                        field.set(deviceSense, attributeValue);
                        break;
                    case "java.util.Date":
                        field.set(deviceSense, new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").parse(attributeValue));
                }
            }
        }
        //使用sql判断重复数据插入
        iDeviceSenseService.dedupInsert(deviceSense);

        //判断设备预警信息 插入异常数据库
        iWarningService.insertWarning(deviceSense);
        logger.info("每6分钟更新一次设备传感数据");
    }

    /**
     * 根据小时，周，天，获取其平均值数据
     * @param type
     * @return
     */
    @GetMapping("/sense")
    public AjaxResult averageList(@RequestParam String type) {
        return AjaxResult.success(iDeviceSenseService.averageList(type));
    }

}
