package com.ruoyi.web.controller.crops;

import cn.hutool.http.HttpUtil;
import com.google.gson.Gson;
import com.google.gson.GsonBuilder;
import com.ruoyi.crops.domain.DeviceSense;
import com.ruoyi.crops.domain.FertigationSense;
import com.ruoyi.crops.domain.gsonBean.GsonDeviceSenseBean;
import com.ruoyi.crops.service.IFertigationSenseService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.lang.reflect.Field;
import java.text.SimpleDateFormat;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import static org.assertj.core.util.DateUtil.now;

@RestController
@RequestMapping
public class FertigationSenseController {
    private static final Logger logger = LoggerFactory.getLogger("scheduled");

    @Value("${url.deviceSense}")
    String url;//指定UR

    @Autowired
    private IFertigationSenseService iFertigationSenseService;

    @Scheduled(fixedDelay = 60 * 60 * 1000)
    public void getsense() throws Exception {
        String deviceId = "645281df92edbc7ee9427230_NHWL-MengLiangGu-Fertigation";
        Map<String, Object> map = new HashMap<>();//存放参数
        map.put("deviceId", deviceId);
        //发送get请求
        String result = HttpUtil.createGet(url).form(map).execute().body();
        //格式化json时间类型数据
        Gson gson = new GsonBuilder().setDateFormat("yyyy/MM/dd HH:mm:ss").create();
        //格式化json，封装到GsonDeviceSenseBean类型
        GsonDeviceSenseBean model = gson.fromJson(result, GsonDeviceSenseBean.class);
        //创建DeviceSense对象，设置deviceId
        FertigationSense fertigationSense = new FertigationSense();
        fertigationSense.setDeviceId(deviceId);
        fertigationSense.setTime(now());
        //通过反射获取成员变量name与json字段匹配入库
        Class clazz = Class.forName("com.ruoyi.crops.domain.FertigationSense");
        for (GsonDeviceSenseBean.AttDataList attDataList : model.data.attDataList) {
            //2.获取成员变量
            String attributeValue = attDataList.attributeValue;
            Field field = clazz.getDeclaredField(attDataList.attributeName);
            //设置私有变量也可访问
            field.setAccessible(true);
            //判断数据类型进行相应转换
            if (attributeValue != null) {
                switch (field.getType().getName()) {
                    case "java.lang.Double":
                        field.set(fertigationSense, Double.valueOf(attributeValue));
                        break;
                    case "java.lang.Integer":
                        field.set(fertigationSense, Integer.valueOf(attributeValue));
                        break;
                    case "java.lang.String":
                        field.set(fertigationSense, attributeValue);
                        break;
//                    case "java.util.Date":
//                        field.set(fertigationSense, new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").parse(attributeValue));
                }
            }
        }
        //使用sql判断重复数据插入
        iFertigationSenseService.insert(fertigationSense);
        logger.info("每小时更新一次水肥一体机设备传感数据");
    }
}
