package com.ruoyi.web.controller.crops;

import cn.hutool.http.HttpUtil;
import com.google.gson.Gson;
import com.google.gson.GsonBuilder;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.crops.domain.gsonBean.GsonMeteorologicalBean;
import com.ruoyi.crops.domain.Meteorological;
import com.ruoyi.crops.service.IMeteorologicalService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.*;

@RestController
@RequestMapping("/crops")
public class MeteorologicalController {
    private static final Logger logger = LoggerFactory.getLogger("scheduled");

    @Value("${Meteorological.url}")
    private String url;
    @Value("${Meteorological.key}")
    private String key;
    @Value("${Meteorological.code}")
    private String code;

    @Autowired
    private IMeteorologicalService iMeteorologicalService;

    @GetMapping("/meterological")
    public AjaxResult selectByTime() {
        if (iMeteorologicalService.selectByTime().isEmpty()) {
            return AjaxResult.warn("今日暂无数据");
        }
        return AjaxResult.success(iMeteorologicalService.selectByTime());
    }

    @Scheduled(fixedDelay = 60 * 60 * 1000)
    public void MeteorologicalInfo() {
        Map<String, Object> map = new HashMap<>();//存放参数
        map.put("city_code", code);
        map.put("key", key);
//        HashMap<String, String> headers = new HashMap<>();//存放请求头，可以存放多个请求头
//        headers.put("xxx", xxx);
        //发送get请求并接收响应数据
        String result = HttpUtil.createGet(url).form(map).execute().body();

        //格式化Json时间类型
        Gson gson = new GsonBuilder().setDateFormat("yyyy-MM-dd HH:mm:ss").create();
        //讲json转换成对应实体类
        GsonMeteorologicalBean model = gson.fromJson(result, GsonMeteorologicalBean.class);
        //判断json是否有数据
        if (model.result != null) {
            ArrayList<GsonMeteorologicalBean.Meteorological> meteorologicalArrayList = model.result;
            //创建一个空的list集合存放json解析的Meteorological实体数据
            List<Meteorological> list = new ArrayList<>();
            //遍历json数组里的参数，存入实体类
            for (GsonMeteorologicalBean.Meteorological meteorological : meteorologicalArrayList) {
                //新建实体类
                Meteorological ml = new Meteorological();
                ml.setWarnId(meteorological.id);
                ml.setTitle(meteorological.title);
                ml.setLevel(meteorological.level);
                ml.setType(meteorological.type);
                ml.setTime(meteorological.time);
                ml.setProvince(meteorological.province);
                ml.setCity(meteorological.city);
                ml.setDistrict(meteorological.district);
                ml.setContent(meteorological.content);
                list.add(ml);
            }
            //从数据库查询出今日的预警信息
            List<Meteorological> meteorologicals = iMeteorologicalService.selectByTime();
            //剔除两个集合里面重复元素根据WarnId和Time
            for (int i = 0; i < list.size(); i++) {
                Meteorological me = list.get(i);
                for (int j = 0; j < meteorologicals.size(); j++) {
                    Meteorological m = meteorologicals.get(j);
                    if (me.getWarnId().equals(m.getWarnId()) && me.getTime().equals(m.getTime())) {
                        list.remove(i);
                        i--;
                    }
                }
            }
            //遍历去重集合插入数据库
            for (Meteorological meteorological : list) {
                iMeteorologicalService.insert(meteorological);
            }
            logger.info("每小时更新1次天气预警");
        } else {
            logger.info("今日暂无预警");
        }

    }
}
