package com.ruoyi.crops.service.impl;

import com.ruoyi.crops.domain.ServiceType;
import com.ruoyi.crops.mapper.ServiceTypeMapper;
import com.ruoyi.crops.service.IGeoServer;
import it.geosolutions.geoserver.rest.GeoServerRESTManager;
import it.geosolutions.geoserver.rest.GeoServerRESTPublisher;
import it.geosolutions.geoserver.rest.decoder.RESTDataStore;
import it.geosolutions.geoserver.rest.encoder.GSLayerEncoder;
import it.geosolutions.geoserver.rest.encoder.GSResourceEncoder;
import it.geosolutions.geoserver.rest.encoder.datastore.GSGeoTIFFDatastoreEncoder;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.io.File;
import java.net.URL;
import java.util.List;

@Service
public class GeoServerImpl implements IGeoServer {
    //GeoServer的连接配置
    @Value("${geoserver.url}")
    private String url;
    @Value("${geoserver.username}")
    private String username;
    @Value("${geoserver.password}")
    private String password;

    @Autowired
    private ServiceTypeMapper serviceTypeMapper;

    @Override
    public String GeoServer(String workSpace, String storeName, String filePath) throws Exception {

        //待创建和发布图层的工作区名称workspace
        //待创建和发布图层的数据存储名称store
        //判断工作区（workspace）是否存在，不存在则创建
        URL u = new URL(url);
        GeoServerRESTManager manager = new GeoServerRESTManager(u, username, password);
        GeoServerRESTPublisher publisher = manager.getPublisher();
        List<String> workspaces = manager.getReader().getWorkspaceNames();
        if (!workspaces.contains(workSpace)) {
            boolean createws = publisher.createWorkspace(workSpace);
            System.out.println("create ws : " + createws);
        } else {
            System.out.println("workspace已经存在了,ws :" + workSpace);
        }

        //判断数据存储（datastore）是否已经存在，不存在则创建

        RESTDataStore restStore = manager.getReader().getDatastore(workSpace, storeName);
        if (restStore == null) {
            GSGeoTIFFDatastoreEncoder gsGeoTIFFDatastoreEncoder = new GSGeoTIFFDatastoreEncoder(storeName);
            gsGeoTIFFDatastoreEncoder.setWorkspaceName(workSpace);
            gsGeoTIFFDatastoreEncoder.setUrl(new URL("file:" + filePath));
            boolean createStore = manager.getStoreManager().create(workSpace, gsGeoTIFFDatastoreEncoder);
            System.out.println("create store (TIFF文件创建状态) : " + createStore);

            boolean publish = manager.getPublisher().publishGeoTIFF(workSpace, storeName, new File(filePath));
            System.out.println("publish (TIFF文件发布状态) : " + publish);

            return "create store (TIFF文件创建状态) : " + createStore + " publish (TIFF文件发布状态) : " + publish;
        } else {
            System.out.println("数据存储已经存在了,store:" + storeName);
        }
        return null;
    }

    @Override
    public int insert(ServiceType serviceType) {
        return serviceTypeMapper.insert(serviceType);
    }
}
