package com.ruoyi.crops.service.impl;

import com.ruoyi.crops.mapper.ServiceTypeMapper;
import com.ruoyi.crops.service.IUploadService;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.web.multipart.MultipartFile;

import java.io.File;
import java.io.IOException;
import java.util.regex.Matcher;

@Service
public class UploadServiceImpl implements IUploadService {
    @Autowired
    private ServiceTypeMapper serviceTypeMapper;
    @Override
    public String upload(String type,MultipartFile file, String fileRoot) throws IOException {
        prepareFilePath(fileRoot);

        // 获取上传文件的原文件名
        String fileName = file.getOriginalFilename();

        if (serviceTypeMapper.selectByfile(fileName)>0){
            return "文件已存在";
        }else {
            // 规则化之后的文件上传根路径
            String normalizeFileRoot = getNormalizeFileRoot(fileRoot);
            // 根据路径和文件名创建目标文件
            File targetFile = new File(normalizeFileRoot, fileName);

            // 如果目标文件存在，删除
            if (targetFile.exists())
                targetFile.delete();

            // 将目标文件进行转移
            file.transferTo(targetFile);

            return String.format("%s\\%s", normalizeFileRoot, fileName);
        }
    }

    /**
     fileRoot：上传文件保存的根路径
     此方法是准备文件上传的路径，如果路径不存在，即创建
     */
    private void prepareFilePath(String fileRoot) {
        File file = new File(normalizePath(fileRoot));
        if (!file.exists())
            file.mkdirs();
    }

    /**
     该方法主要对文件路径进行规则化，如：D:\\\360Browser\///360Chrome\\//,
     像这种路径就不正确，此方法可以将路径规则化为：D:\360Browser\360Chrome
     */
    private String getNormalizeFileRoot(String fileRoot) {
        return normalizePath(fileRoot);
    }
    public static String normalizePath(String path) {
        String result = path.replaceAll("/+", Matcher.quoteReplacement(File.separator));
        return result.replaceAll("\\\\+", Matcher.quoteReplacement(File.separator));
    }
}
