package com.ruoyi.crops.service.impl;

import com.ruoyi.crops.domain.DeviceSense;
import com.ruoyi.crops.domain.WarningInformation;
import com.ruoyi.crops.mapper.WarningMapper;
import com.ruoyi.crops.service.IWarningService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.List;

import static cn.hutool.core.date.DateTime.now;

@Service
public class WarningServiceImpl implements IWarningService {
    @Autowired
    private WarningMapper warningMapper;
    @Override
    public List<WarningInformation> selectByTime(Date startTime,Date endTime) {
        return warningMapper.selectByTime(startTime,endTime);
    }

    @Override
    public int insert(WarningInformation warningInformation) {
        return warningMapper.insert(warningInformation);
    }

    @Override
    public int insertWarning(DeviceSense deviceSense) {
        WarningInformation warningInformation = new WarningInformation();
        Double sunlight = deviceSense.getSunlight();
        if (sunlight > 2) {
            warningInformation.setMonitoringIndicators("光照强度");
            warningInformation.setMonitoringValues(sunlight);
            warningInformation.setAbnormalCause("偏高");
            warningInformation.setWarningTime(deviceSense.getTime());
            warningInformation.setAaus("Lux");
            warningMapper.insert(warningInformation);

        } if (sunlight < 1) {
            warningInformation.setMonitoringIndicators("光照强度");
            warningInformation.setMonitoringValues(sunlight);
            warningInformation.setAbnormalCause("偏低");
            warningInformation.setWarningTime(deviceSense.getTime());
            warningInformation.setAaus("Lux");
            warningMapper.insert(warningInformation);
        }
        //空气温度[°C]
        Double airTemp = deviceSense.getAirTemp();
        if (airTemp>22.6){
            warningInformation.setMonitoringIndicators("空气温度");
            warningInformation.setMonitoringValues(airTemp);
            warningInformation.setAbnormalCause("偏高");
            warningInformation.setWarningTime(deviceSense.getTime());
            warningInformation.setAaus("°C");
            warningMapper.insert(warningInformation);
        }
        if (airTemp<22.2){
            warningInformation.setMonitoringIndicators("空气温度");
            warningInformation.setMonitoringValues(airTemp);
            warningInformation.setAbnormalCause("偏低");
            warningInformation.setWarningTime(deviceSense.getTime());
            warningInformation.setAaus("°C");
            warningMapper.insert(warningInformation);
        }
        //空气湿度[%]
        Double airHumidity = deviceSense.getAirHumidity();
        if (airHumidity>48){
            warningInformation.setMonitoringIndicators("空气湿度");
            warningInformation.setMonitoringValues(airHumidity);
            warningInformation.setAbnormalCause("偏高");
            warningInformation.setWarningTime(deviceSense.getTime());
            warningInformation.setAaus("%");
            warningMapper.insert(warningInformation);
        }
        if (airHumidity<45){
            warningInformation.setMonitoringIndicators("空气湿度");
            warningInformation.setMonitoringValues(airHumidity);
            warningInformation.setAbnormalCause("偏低");
            warningInformation.setWarningTime(deviceSense.getTime());
            warningInformation.setAaus("%");
            warningMapper.insert(warningInformation);
        }
        //土壤温度[°C]
        Double soilTemp = deviceSense.getSoilTemp();
        if (soilTemp>22.8){
            warningInformation.setMonitoringIndicators("土壤温度");
            warningInformation.setMonitoringValues(soilTemp);
            warningInformation.setAbnormalCause("偏高");
            warningInformation.setWarningTime(deviceSense.getTime());
            warningInformation.setAaus("°C");
            warningMapper.insert(warningInformation);
        }
        if (soilTemp<22.7){
            warningInformation.setMonitoringIndicators("土壤温度");
            warningInformation.setMonitoringValues(soilTemp);
            warningInformation.setAbnormalCause("偏低");
            warningInformation.setWarningTime(deviceSense.getTime());
            warningInformation.setAaus("°C");
            warningMapper.insert(warningInformation);
        }
        //土壤湿度[%]
        Double soilHumidity = deviceSense.getSoilHumidity();
        if (soilHumidity>3){
            warningInformation.setMonitoringIndicators("土壤湿度");
            warningInformation.setMonitoringValues(soilHumidity);
            warningInformation.setAbnormalCause("偏高");
            warningInformation.setWarningTime(deviceSense.getTime());
            warningInformation.setAaus("%");
            warningMapper.insert(warningInformation);
        }
        if (soilHumidity<1){
            warningInformation.setMonitoringIndicators("土壤湿度");
            warningInformation.setMonitoringValues(soilHumidity);
            warningInformation.setAbnormalCause("偏低");
            warningInformation.setWarningTime(deviceSense.getTime());
            warningInformation.setAaus("%");
            warningMapper.insert(warningInformation);
        }

        //二氧化碳浓度[ppm]
        Double co2_ = deviceSense.getCO2_();
        if (co2_>800){
            warningInformation.setMonitoringIndicators("二氧化碳浓度");
            warningInformation.setMonitoringValues(co2_);
            warningInformation.setAbnormalCause("偏高");
            warningInformation.setWarningTime(deviceSense.getTime());
            warningInformation.setAaus("ppm");
            warningMapper.insert(warningInformation);
        }
        if (co2_<530){
            warningInformation.setMonitoringIndicators("二氧化碳浓度");
            warningInformation.setMonitoringValues(co2_);
            warningInformation.setAbnormalCause("偏低");
            warningInformation.setWarningTime(deviceSense.getTime());
            warningInformation.setAaus("ppm");
            warningMapper.insert(warningInformation);
        }
        return 0;
    }
}
